@@ -19,7 +19,7 @@
 class MagicLabel : TQObject
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
   private:
     TQString prefix;
@@ -33,8 +33,8 @@ class MagicLabel : TQObject
     void getCommandOutput();
 
   private slots:
-    void processExited(KProcess* proc);
-    void receivedStdout(KProcess *proc, char *buffer, int buflen);
+    void processExited(TDEProcess* proc);
+    void receivedStdout(TDEProcess *proc, char *buffer, int buflen);
 
   public:
     MagicLabel(TQString s, bool translate);
